# @nativescript/flutter

Use Flutter with NativeScript projects by creating a [Flutter module](https://docs.flutter.dev/add-to-app) in the root of your project.

```javascript
npm install @nativescript/flutter
```

## Usage

You can use Flutter full screen as the entire app or intermix Flutter views throughout your NativeScript app anywhere you'd like.

### 1. Init the Flutter Engine

Be sure to initialize the Flutter engine before bootstrapping your app, typically in `app.ts` or `main.ts`:

```ts
import { init } from '@nativescript/flutter';
init();

// bootstrap app...
```

### 2. Configure platforms for usage

- iOS: `App_Resources/iOS/Podfile` should contain a reference your Flutter module.

Assuming a Flutter module in a folder named `flutter_views` exists at the root of your NativeScript project, configure as follows:

```ruby
platform :ios, '14.0'

flutter_application_path = '../../flutter_views'
load File.join(flutter_application_path, '.ios', 'Flutter', 'podhelper.rb')
install_all_flutter_pods(flutter_application_path)

post_install do |installer|
    flutter_post_install(installer) if defined?(flutter_post_install)
end
```

Add Flutter debug permissions to `App_Resources/iOS/Info.plist`:

```xml
<key>NSLocalNetworkUsageDescription</key>
<string>Allow Flutter tools to debug your Skia views.</string>
<key>NSBonjourServices</key>
<array>
  <string>_dartobservatory._tcp</string>
</array>
```

### 3. Configure your Dart code to have named entry points

- `main.dart`

```ts
@pragma('vm:entry-point')
void myFlutterView() => runApp(const MyFlutterView());
```

### 4. Use Flutter anywhere

```xml
<Flutter id="myFlutterView"></Flutter>
```

## License

Apache License Version 2.0
